@@ -1,4 +1,4 @@
-__version__ = "5.0.3"
+__version__ = "5.0.14"
 
 from .logger import LogLevelEnum, logger_init, log_llm_error
 from .models import (
@@ -17,3 +17,6 @@ from .xml_parser import XMLParser
 from .parallel_map import parallel_map
 from .models.tracks import TrackInfo, DomainInfo
 from .api.chat_manager_api import ChatManagerAPI
+from .api.content_interpreter_api import ContentInterpreterAPI, Interpretation
+from .api.content_interpreter_remote_api import ContentInterpreterRemoteAPI
+from .api.text_processor_api import TextProcessorAPI
