@@ -42,6 +42,11 @@ def try_parse_float(text: str) -> float | None:
     except (ValueError, TypeError):
         return None
 
+def try_parse_bool(v: str | bool) -> bool:
+    if isinstance(v, bool):
+        return v
+    return v.lower() in ("yes", "true", "t", "1")
+
 def pretty_line(text: str, cut_count: int = 100) -> str:
     if len(text) > 100:
         text_cut = text[:cut_count]
